@@ -30,5 +30,4 @@
  * under the License.
  */
 
-require('./child_process');
-require('./lodash_template');
\ No newline at end of file
+require("./child_process");
\ No newline at end of file
